﻿using System;
using System.Windows.Forms;

namespace $safeprojectname$ {
	public partial class Form1 : Form {

		// Excel アプリケーション
		private dynamic excelApp = null;
		// Excel ブック
		private dynamic workBook = null;
		// Excel のパス
		private string path = null;

		// *********************
		// コンストラクタ
		// *********************
		public Form1() {
			InitializeComponent();
		}

		// *********************
		// 書き込みテスト
		// *********************
		private void buttonTest_Click(object sender, EventArgs e) {

			// ブックを開いていない場合はなにもしない
			if (workBook == null) {
				return;
			}

			// セル用変数
			dynamic cell;
			// 行と列より、セルオブジェクト(アクティブシート)
			cell = workBook.ActiveSheet.Cells(numericRow.Value, numericColumn.Value);
			// セルに値をセット
			cell.Value = textString.Text;

		}

		// *********************
		// アクティブにする
		// *********************
		private void buttonActive_Click(object sender, EventArgs e) {

			// ブックを開いていない場合はなにもしない
			if (workBook == null) {
				return;
			}

			string sheetName = listBoxSheet.Text;
			// アクティブにする
			workBook.Sheets(sheetName).Activate();
			// 先頭へスクロール
			workBook.Sheets(sheetName).Range("A1").Select();

		}

		// *********************
		// 初期処理
		// *********************
		private void Form1_Load(object sender, EventArgs e) {

			excelApp = Activator.CreateInstance(Type.GetTypeFromProgID("Excel.Application"));
			excelApp.Visible = true;

		}

		// *********************
		// 終了処理
		// *********************
		private void Form1_FormClosed(object sender, FormClosedEventArgs e) {

			if ( excelApp != null) {
				if (workBook != null) {
					// 保存した事にする
					workBook.Saved = true;
				}
				excelApp.Quit();
			}
			System.Runtime.InteropServices.Marshal.ReleaseComObject(excelApp);

		}

		// *********************
		// ブックを開く
		// *********************
		private void 開く_Click(object sender, EventArgs e) {

			if (workBook != null) {
				MessageBox.Show(this, "ブックは一つしか開く事ができません");
				return;
			}

			// Helper クラスでファイルを開く
			path = Helper.OpenFileDialog();
			if ( path != null ) {
				// Excel でブックを開く
				workBook = excelApp.Workbooks.Open(path);
				// リストボックス初期化
				listBoxSheet.Items.Clear();
				// シートの数によりループ
				for( int i = 1; i <= workBook.Sheets.Count; i++ ) {
					// シート名をリストボックスにセット
					listBoxSheet.Items.Add(workBook.Sheets(i).Name);
					// アクティブシートの場合
					if (workBook.ActiveSheet.Name == workBook.Sheets(i).Name)
					{
						// 選択して
						listBoxSheet.SelectedIndex = i-1;
						// 先頭へスクロール
						workBook.ActiveSheet.Range("A1").Select();
					}
				}
				// リストボックスを使用可能に
				listBoxSheet.Enabled = true;
			}

		}

		// *********************
		// 閉じる
		// *********************
		private void 閉じる_Click(object sender, EventArgs e) {

			closeExcel(1);

		}

		// *********************
		// 保存して閉じる
		// *********************
		private void 保存して閉じる_Click(object sender, EventArgs e) {

			closeExcel(2);
		}

		// *********************
		// Excel を閉じる
		// *********************
		private void closeExcel(int type)
		{
			if (workBook != null)
			{
				if (type == 1)
				{
					// 保存した事にする
					workBook.Saved = true;
				}
				if (type == 2)
				{
					// 保存
					workBook.Save();
				}
				workBook.Close();
				workBook = null;
			}

			// クリア
			listBoxSheet.Items.Clear();
			// リストボックスを使用不可にして
			listBoxSheet.Enabled = false;
			// 選択しない
			listBoxSheet.SelectedIndex = -1;
		}

		// *********************
		// 最大化
		// *********************
		private void 最大化_Click(object sender, EventArgs e) {

			excelApp.WindowState = Helper.xlMaximized;

		}

		// *********************
		// 標準
		// *********************
		private void 標準_Click(object sender, EventArgs e) {

			excelApp.WindowState = Helper.xlNormal;

		}

	}
}
